@@ -4,6 +4,7 @@ import os
 
 from embit.liquid.networks import get_network
 from flask_babel import lazy_gettext as _
+from requests.exceptions import ConnectionError
 from .helpers import is_testnet, is_liquid
 from .liquid.rpc import LiquidRPC
 from .persistence import write_node
@@ -11,7 +12,6 @@ from .rpc import (
     BitcoinRPC,
     RpcError,
     autodetect_rpc_confs,
-    detect_rpc_confs,
     get_default_datadir,
 )
 
@@ -40,6 +40,7 @@ class Node:
         protocol,
         external_node,
         fullpath,
+        node_type,
         manager,
     ):
         """Constructor for your Node.
@@ -55,6 +56,7 @@ class Node:
         :param protocol: Usually https or http
         :param external_node: should be True for Node and False for InternalNode
         :param fullpath: it's assumed that you want to store it on disk AND decide about the fullpath upfront
+        :param node_type: either "ELM" or "BTC", will impact autodetection (datadir and Env-vars)
         :param manager: A NodeManager instance which will get notified if the Node's name changes, the proxy_url will get copied from the manager as well
         """
         self.name = name
@@ -68,12 +70,12 @@ class Node:
         self.protocol = protocol
         self.external_node = external_node
         self.fullpath = fullpath
+        self._node_type = node_type
         self.manager = manager
         self.proxy_url = manager.proxy_url
         self.only_tor = manager.only_tor
         self.rpc = self.get_rpc()
         self._asset_labels = None
-
         self.check_info()
 
     @classmethod
@@ -82,7 +84,8 @@ class Node:
         name = node_dict.get("name", "")
         alias = node_dict.get("alias", default_alias)
         autodetect = node_dict.get("autodetect", True)
-        datadir = node_dict.get("datadir", get_default_datadir())
+        node_type = node_dict.get("node_type", "BTC")
+        datadir = node_dict.get("datadir", get_default_datadir(node_type=node_type))
         user = node_dict.get("user", "")
         password = node_dict.get("password", "")
         port = node_dict.get("port", None)
@@ -103,6 +106,7 @@ class Node:
             protocol,
             external_node,
             fullpath,
+            node_type,
             manager,
         )
 
@@ -121,6 +125,7 @@ class Node:
             "protocol": self.protocol,
             "external_node": self.external_node,
             "fullpath": self.fullpath,
+            "node_type": self.node_type,
         }
 
     def get_rpc(self):
@@ -135,11 +140,13 @@ class Node:
         if self.autodetect:
             if self.port:
                 rpc_conf_arr = autodetect_rpc_confs(
-                    datadir=os.path.expanduser(self.datadir), port=self.port
+                    self.node_type,
+                    datadir=os.path.expanduser(self.datadir),
+                    port=self.port,
                 )
             else:
                 rpc_conf_arr = autodetect_rpc_confs(
-                    datadir=os.path.expanduser(self.datadir)
+                    self.node_type, datadir=os.path.expanduser(self.datadir)
                 )
             if len(rpc_conf_arr) > 0:
                 rpc = BitcoinRPC(
@@ -172,8 +179,17 @@ class Node:
             if is_liquid(res.get("chain")):
                 # convert to LiquidRPC class
                 rpc = LiquidRPC.from_bitcoin_rpc(rpc)
+        except RpcError as rpce:
+            if rpce.status_code == 401:
+                return rpc  # The user is failing to configure correctly
+            logger.error(rpce)
+            return None
+        except ConnectionError as e:
+            logger.error(f"{e} while get_rpc")
+            return None
         except Exception as e:
-            return rpc
+            logger.exception(e)
+            return None
         if rpc.test_connection():
             return rpc
         else:
@@ -298,7 +314,7 @@ class Node:
                         ]
                     )
                 except Exception as e:
-                    logger.error(e)
+                    logger.exception(e)
             self._info = {"chain": None}
             self._network_info = {"subversion": "", "version": 999999}
 
@@ -335,20 +351,21 @@ class Node:
                 rpc.listwallets()
                 r["tests"]["wallets"] = True
             except RpcError as rpce:
-                logger.error(rpce)
+                logger.info(f"Couldn't list wallets while test_rpc {rpce}")
                 r["tests"]["wallets"] = False
                 r["err"] = "Wallets disabled"
 
             r["out"] = json.dumps(rpc.getblockchaininfo(), indent=4)
         except ConnectionError as e:
-            logger.error("Caught an ConnectionError while test_rpc: %s", e)
+            logger.info("Caught an ConnectionError while test_rpc: %s", e)
 
             r["tests"]["connectable"] = False
             r["err"] = _("Failed to connect!")
             r["code"] = -1
         except RpcError as rpce:
-            logger.error("Caught an RpcError while test_rpc: %s", rpce)
-            logger.error(rpce.status_code)
+            logger.info(
+                f"Caught an RpcError while test_rpc status_code: {rpce.status_code} error_code:{rpce.error_code}"
+            )
             r["tests"]["connectable"] = True
             r["code"] = rpc.r.status_code
             if rpce.status_code == 401:
@@ -418,6 +435,17 @@ class Node:
     def bitcoin_core_version_raw(self):
         return self.network_info["version"]
 
+    @property
+    def taproot_support(self):
+        try:
+            # currently only master branch supports tr() descriptors
+            # TODO: replace to 220000
+            return (self.bitcoin_core_version_raw >= 219900) and (
+                self.info.get("softforks", {}).get("taproot", {}).get("active", False)
+            )
+        except Exception as e:
+            return False
+
     @property
     def chain(self):
         return self.info["chain"]
@@ -428,11 +456,14 @@ class Node:
 
     @property
     def asset_labels(self):
+        if not self.is_liquid:
+            return {}
         if self._asset_labels is None:
             asset_labels = self.rpc.dumpassetlabels()
             assets = {}
+            LBTC = "LBTC" if self.chain == "liquidv1" else "tLBTC"
             for k in asset_labels:
-                assets[asset_labels[k]] = k if k != "bitcoin" else "LBTC"
+                assets[asset_labels[k]] = k if k != "bitcoin" else LBTC
             self._asset_labels = assets
         return self._asset_labels
 
@@ -447,6 +478,13 @@ class Node:
         else:
             return self._rpc
 
+    @property
+    def node_type(self):
+        """either BTC or ELM. This is (only) used to enable autodetection and should get specified with the Constructor"""
+        if hasattr(self, "_node_type"):
+            return self._node_type
+        return "BTC"
+
     @rpc.setter
     def rpc(self, value):
         if hasattr(self, "_rpc") and self._rpc != value:
