@@ -1,7 +1,7 @@
 from datetime import datetime
 from flask import current_app as app
 from flask import Blueprint
-from jinja2 import contextfilter
+from jinja2 import pass_context
 from ..helpers import to_ascii20
 
 filters_bp = Blueprint("filters", __name__)
@@ -9,41 +9,43 @@ filters_bp = Blueprint("filters", __name__)
 ############### filters ##################
 
 
-@contextfilter
+@pass_context
 @filters_bp.app_template_filter("ascii20")
 def ascii20(context, name):
     return to_ascii20(name)
 
 
-@contextfilter
+@pass_context
 @filters_bp.app_template_filter("unique_len")
 def unique_len(context, arr):
     return len(set(arr))
 
 
-@contextfilter
+@pass_context
 @filters_bp.app_template_filter("datetime")
 def timedatetime(context, s):
     return format(datetime.fromtimestamp(s), "%d.%m.%Y %H:%M")
 
 
-@contextfilter
+@pass_context
 @filters_bp.app_template_filter("btcamount")
 def btcamount(context, value):
-    if value < 0:
+    if value is None:
+        return "Unknown"
+    if value < 0 and app.specter.is_liquid:
         return "Confidential"
     value = round(float(value), 8)
     return "{:,.8f}".format(value).rstrip("0").rstrip(".")
 
 
-@contextfilter
+@pass_context
 @filters_bp.app_template_filter("btc2sat")
 def btc2sat(context, value):
     value = int(round(float(value) * 1e8))
     return f"{value}"
 
 
-@contextfilter
+@pass_context
 @filters_bp.app_template_filter("feerate")
 def feerate(context, value):
     value = float(value) * 1e8
@@ -54,12 +56,14 @@ def feerate(context, value):
     return "{:,.2f}".format(value).rstrip("0").rstrip(".")
 
 
-@contextfilter
+@pass_context
 @filters_bp.app_template_filter("btcunitamount")
 def btcunitamount(context, value):
     if app.specter.hide_sensitive_info:
         return "#########"
-    if value < 0:
+    if value is None:
+        return "Unknown"
+    if value < 0 and app.specter.is_liquid:
         return "Confidential"
     if app.specter.unit != "sat":
         return btcamount(context, value)
@@ -67,11 +71,13 @@ def btcunitamount(context, value):
     return "{:,.0f}".format(round(value * 1e8))
 
 
-@contextfilter
+@pass_context
 @filters_bp.app_template_filter("altunit")
 def altunit(context, value):
     if app.specter.hide_sensitive_info:
         return "########"
+    if value is None:
+        return "Can't be calculated"
     if value < 0:
         return "-"
     if app.specter.price_check and (app.specter.alt_rate and app.specter.alt_symbol):
@@ -87,14 +93,14 @@ def altunit(context, value):
     return ""
 
 
-@contextfilter
+@pass_context
 @filters_bp.app_template_filter("bytessize")
 def bytessize(context, value):
     value = float(value)
     return "{:,.0f}".format(value / float(1 << 30)) + " GB"
 
 
-@contextfilter
+@pass_context
 @filters_bp.app_template_filter("assetlabel")
 def assetlabel(context, asset):
     if app.specter.hide_sensitive_info:
